Components
==========

Subclasses of `Core` `Mechanisms <Mechanism>` and `Projections <Projection>` that implement specialized operations
used by `Compositions` in the `Library`.

.. toctree::
   :maxdepth: 3

   Mechanisms
   Projections
